@@ -31,3 +31,11 @@ pub fn new_application_error<T: Serialize>(code: &str, payload: T) -> Error {
         message: to_string_pretty(&payload).unwrap(),
     }
 }
+
+pub fn new_server_error(msg: &str) -> Error {
+    Error {
+        status: String::from("500"),
+        code: String::from("SERVER_ERROR"),
+        message: msg.to_string(),
+    }
+}
